import 'dart:async';

import 'package:flutter/services.dart';

import 'ads_events.dart';
export 'ads_events.dart';

abstract class AdsFlutterEventHandler {
  final Function(AdsFlutterAdEvent, Map<String, dynamic>?)? _listener;

  AdsFlutterEventHandler(Function(AdsFlutterAdEvent, Map<String, dynamic>?)? listener)
      : _listener = listener;

  Future<void> handleEvent(MethodCall call) async {
    if (_listener == null) {
      return;
    }
    switch (call.method) {
      case 'loaded':
        _listener!(AdsFlutterAdEvent.loaded, null);
        break;
      case 'failedToLoad':
        _listener!(AdsFlutterAdEvent.failedToLoad,
            Map<String, dynamic>.from(call.arguments));
        break;
      case 'clicked':
        _listener!(AdsFlutterAdEvent.clicked, null);
        break;
      case 'impression':
        _listener!(AdsFlutterAdEvent.impression, null);
        break;
      case 'opened':
        _listener!(AdsFlutterAdEvent.opened, null);
        break;
      case 'leftApplication':
        _listener!(AdsFlutterAdEvent.leftApplication, null);
        break;
      case 'closed':
        _listener!(AdsFlutterAdEvent.closed, null);
        break;
      case 'completed':
        _listener!(AdsFlutterAdEvent.completed, null);
        break;
      case 'rewarded':
        _listener!(
            AdsFlutterAdEvent.rewarded, Map<String, dynamic>.from(call.arguments));
        break;
      case 'started':
        _listener!(AdsFlutterAdEvent.started, null);
        break;
    }
  }
}
